@@ -59,7 +59,6 @@ import org.mortbay.log.Log;
  * ldaploginmodule {
  *    org.mortbay.jetty.plus.jaas.spi.LdapLoginModule required
  *    debug="true"
- *    useLdaps="false"
  *    contextFactory="com.sun.jndi.ldap.LdapCtxFactory"
  *    hostname="ldap.example.com"
  *    port="389"
@@ -170,11 +169,6 @@ public class LdapLoginModule extends AbstractLoginModule
      * login checks, set this to true
      */
     private boolean _forceBindingLogin = false;
-    
-    /**
-     * When true changes the protocol to ldaps
-     */
-    private boolean _useLdaps = false;
 
     private DirContext _rootContext;
 
@@ -200,6 +194,10 @@ public class LdapLoginModule extends AbstractLoginModule
         }
 
         pwdCredential = convertCredentialLdapToJetty(pwdCredential);
+
+        //String md5Credential = Credential.MD5.digest("foo");
+        //byte[] ba = digestMD5("foo");
+        //System.out.println(md5Credential + "  " + ba );
         Credential credential = Credential.getCredential(pwdCredential);
         List roles = getUserRoles(_rootContext, username);
 
@@ -482,7 +480,9 @@ public class LdapLoginModule extends AbstractLoginModule
         List roles = getUserRolesByDn(dirContext, userDn);
 
         UserInfo userInfo = new UserInfo(username, null, roles);
+
         setCurrentUser(new JAASUserInfo(userInfo));
+
         setAuthenticated(true);
 
         return true;
@@ -538,12 +538,7 @@ public class LdapLoginModule extends AbstractLoginModule
         {
             _forceBindingLogin = Boolean.valueOf((String) options.get("forceBindingLogin")).booleanValue();
         }
-        
-        if (options.containsKey("useLdaps"))
-        {
-            _useLdaps = Boolean.parseBoolean((String) options.get("useLdaps"));
-        }     
-        
+
         _userObjectClass = getOption(options, "userObjectClass", _userObjectClass);
         _userRdnAttribute = getOption(options, "userRdnAttribute", _userRdnAttribute);
         _userIdAttribute = getOption(options, "userIdAttribute", _userIdAttribute);
@@ -562,35 +557,35 @@ public class LdapLoginModule extends AbstractLoginModule
             throw new RuntimeException("Unable to establish root context", ex);
         }
     }
-
+   
     public boolean commit() throws LoginException 
     {
-        try 
-        {
-            _rootContext.close();
-        } 
-        catch (NamingException e) 
-        {
-            throw new LoginException("error closing root context: " + e.getMessage());
-        }
+		try 
+		{
+			_rootContext.close();
+		} 
+		catch (NamingException e) 
+		{
+			throw new LoginException("error closing root context: " + e.getMessage());
+		}
 
-        return super.commit();
-    }
+		return super.commit();
+	}
 
-    public boolean abort() throws LoginException 
-    {
-        try 
-        {
-            _rootContext.close();
-        } 
-        catch (NamingException e) 
-        {
-            throw new LoginException("error closing root context: " + e.getMessage());
-        }
-
-        return super.abort();
-    }
+	public boolean abort() throws LoginException 
+	{
+		try 
+		{
+			_rootContext.close();
+		} 
+		catch (NamingException e) 
+		{
+			throw new LoginException("error closing root context: " + e.getMessage());
+		}
 
+		return super.abort();
+	}
+    
     private String getOption(Map options, String key, String defaultValue)
     {
         Object value = options.get(key);
@@ -615,7 +610,14 @@ public class LdapLoginModule extends AbstractLoginModule
 
         if (_hostname != null)
         {
-            env.put(Context.PROVIDER_URL, (_useLdaps?"ldaps://":"ldap://") + _hostname + (_port==0?"":":"+_port) +"/");
+            if (_port != 0)
+            {
+                env.put(Context.PROVIDER_URL, "ldap://" + _hostname + ":" + _port + "/");
+            }
+            else
+            {
+                env.put(Context.PROVIDER_URL, "ldap://" + _hostname + "/");
+            }
         }
 
         if (_authenticationMethod != null)
