@@ -17,6 +17,7 @@ package org.mortbay.terracotta.servlet;
 import java.io.IOException;
 import java.util.Collections;
 import java.util.Random;
+
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServlet;
 import javax.servlet.http.HttpServletRequest;
@@ -30,7 +31,7 @@ import org.mortbay.jetty.servlet.Context;
 import org.testng.annotations.Test;
 
 /**
- * @version $Revision: 1645 $ $Date: 2009-09-15 12:31:07 +0200 (Tue, 15 Sep 2009) $
+ * @version $Revision: 1319 $ $Date: 2008-11-13 23:55:54 +0000 (jeu. 13 nov. 2008) $
  */
 public class ClientCrossContextSessionTest
 {
@@ -65,8 +66,6 @@ public class ClientCrossContextSessionTest
                 assert exchangeA.getResponseStatus() == HttpServletResponse.SC_OK;
                 String sessionCookie = exchangeA.getResponseFields().getStringField("Set-Cookie");
                 assert sessionCookie != null;
-                // Mangle the cookie, replacing Path with $Path, etc.
-                sessionCookie = sessionCookie.replaceFirst("(\\W)(P|p)ath=", "$1\\$Path=");
 
                 // Perform a request to contextB with the same session cookie
                 ContentExchange exchangeB = new ContentExchange(true);
