@@ -17,6 +17,7 @@ package org.mortbay.terracotta.servlet;
 import java.io.IOException;
 import java.io.PrintWriter;
 import java.util.Random;
+
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServlet;
 import javax.servlet.http.HttpServletRequest;
@@ -29,7 +30,7 @@ import org.mortbay.jetty.client.HttpClient;
 import org.testng.annotations.Test;
 
 /**
- * @version $Revision: 1645 $ $Date: 2009-09-15 12:31:07 +0200 (Tue, 15 Sep 2009) $
+ * @version $Revision: 1319 $ $Date: 2008-11-13 23:55:54 +0000 (jeu. 13 nov. 2008) $
  */
 public class ImmortalSessionTest
 {
@@ -61,9 +62,6 @@ public class ImmortalSessionTest
                 assert exchange.getResponseStatus() == HttpServletResponse.SC_OK;
                 String sessionCookie = exchange.getResponseFields().getStringField("Set-Cookie");
                 assert sessionCookie != null;
-                // Mangle the cookie, replacing Path with $Path, etc.
-                sessionCookie = sessionCookie.replaceFirst("(\\W)(P|p)ath=", "$1\\$Path=");
-
                 String response = exchange.getResponseContent();
                 assert response.trim().equals(String.valueOf(value));
 
