@@ -16,6 +16,7 @@ package org.mortbay.terracotta.servlet;
 
 import java.io.IOException;
 import java.util.Random;
+
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServlet;
 import javax.servlet.http.HttpServletRequest;
@@ -30,7 +31,7 @@ import org.testng.annotations.Test;
 /**
  * Goal of the test is to be sure that invalidating a session on one node
  * result in the session being unavailable in the other node also.
- * @version $Revision: 1645 $ $Date: 2009-09-15 12:31:07 +0200 (Tue, 15 Sep 2009) $
+ * @version $Revision: 1319 $ $Date: 2008-11-13 23:55:54 +0000 (jeu. 13 nov. 2008) $
  */
 public class InvalidationSessionTest
 {
@@ -71,8 +72,6 @@ public class InvalidationSessionTest
                     assert exchange1.getResponseStatus() == HttpServletResponse.SC_OK;
                     String sessionCookie = exchange1.getResponseFields().getStringField("Set-Cookie");
                     assert sessionCookie != null;
-                    // Mangle the cookie, replacing Path with $Path, etc.
-                    sessionCookie = sessionCookie.replaceFirst("(\\W)(P|p)ath=", "$1\\$Path=");
 
                     // Be sure the session is also present in node2
                     ContentExchange exchange2 = new ContentExchange(true);
