@@ -21,6 +21,7 @@ import java.util.concurrent.CyclicBarrier;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
 import java.util.concurrent.TimeUnit;
+
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServlet;
 import javax.servlet.http.HttpServletRequest;
@@ -33,7 +34,7 @@ import org.mortbay.jetty.client.HttpClient;
 import org.testng.annotations.Test;
 
 /**
- * @version $Revision: 1645 $ $Date: 2009-09-15 12:31:07 +0200 (Tue, 15 Sep 2009) $
+ * @version $Revision: 1457 $ $Date: 2009-02-26 15:09:48 +0000 (jeu. 26 févr. 2009) $
  */
 public class LightLoadTest
 {
@@ -78,8 +79,6 @@ public class LightLoadTest
                         assert exchange1.getResponseStatus() == HttpServletResponse.SC_OK;
                         String sessionCookie = exchange1.getResponseFields().getStringField( "Set-Cookie" );
                         assert sessionCookie != null;
-                        // Mangle the cookie, replacing Path with $Path, etc.
-                        sessionCookie = sessionCookie.replaceFirst("(\\W)(P|p)ath=", "$1\\$Path=");
 
                         ExecutorService executor = Executors.newCachedThreadPool();
                         int clientsCount = 50;
