@@ -17,6 +17,7 @@ package org.mortbay.terracotta.servlet;
 import java.io.IOException;
 import java.io.PrintWriter;
 import java.util.Random;
+
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServlet;
 import javax.servlet.http.HttpServletRequest;
@@ -29,7 +30,7 @@ import org.mortbay.jetty.client.HttpClient;
 import org.testng.annotations.Test;
 
 /**
- * @version $Revision: 1645 $ $Date: 2009-09-15 12:31:07 +0200 (Tue, 15 Sep 2009) $
+ * @version $Revision: 1256 $ $Date: 2008-10-17 15:50:04 +0100 (ven. 17 oct. 2008) $
  */
 public class SessionMigrationTest
 {
@@ -67,8 +68,6 @@ public class SessionMigrationTest
                     assert exchange1.getResponseStatus() == HttpServletResponse.SC_OK;
                     String sessionCookie = exchange1.getResponseFields().getStringField("Set-Cookie");
                     assert sessionCookie != null;
-                    // Mangle the cookie, replacing Path with $Path, etc.
-                    sessionCookie = sessionCookie.replaceFirst("(\\W)(P|p)ath=", "$1\\$Path=");
 
                     // Perform a request to server2 using the session cookie from the previous request
                     // This should migrate the session from server1 to server2.
