@@ -23,6 +23,7 @@ import java.util.concurrent.CyclicBarrier;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
 import java.util.concurrent.TimeUnit;
+
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServlet;
 import javax.servlet.http.HttpServletRequest;
@@ -38,7 +39,7 @@ import org.mortbay.jetty.webapp.WebAppContext;
 import org.testng.annotations.Test;
 
 /**
- * @version $Revision: 1645 $ $Date: 2009-09-15 12:31:07 +0200 (Tue, 15 Sep 2009) $
+ * @version $Revision: 1319 $ $Date: 2008-11-13 23:55:54 +0000 (jeu. 13 nov. 2008) $
  */
 public class TIMLightLoadTest
 {
@@ -104,8 +105,6 @@ public class TIMLightLoadTest
                     String sessionCookie = exchange1.getResponseFields().getStringField("Set-Cookie");
                     assert sessionCookie != null;
                     System.out.println("sessionCookie = " + sessionCookie);
-                    // Mangle the cookie, replacing Path with $Path, etc.
-                    sessionCookie = sessionCookie.replaceFirst("(\\W)(P|p)ath=", "$1\\$Path=");
 
                     ExecutorService executor = Executors.newCachedThreadPool();
                     int clientsCount = 50;
