@@ -15,7 +15,6 @@
 package org.mortbay.jetty.ajp;
 
 import java.io.IOException;
-import java.io.UnsupportedEncodingException;
 import java.util.HashMap;
 import java.util.Iterator;
 
@@ -26,7 +25,6 @@ import org.mortbay.io.EndPoint;
 import org.mortbay.jetty.*;
 import org.mortbay.jetty.HttpFields.Field;
 import org.mortbay.log.Log;
-import org.mortbay.util.StringUtil;
 import org.mortbay.util.TypeUtil;
 
 /**
@@ -729,7 +727,7 @@ public class Ajp13Generator extends AbstractGenerator
     }
 
     /* ------------------------------------------------------------ */
-    private void addString(String str) throws UnsupportedEncodingException
+    private void addString(String str)
     {
         if (str == null)
         {
@@ -739,7 +737,7 @@ public class Ajp13Generator extends AbstractGenerator
 
         // TODO - need to use a writer to convert, to avoid this hacky
         // conversion and temp buffer
-        byte[] b = str.getBytes(StringUtil.__ISO_8859_1);
+        byte[] b = str.getBytes();
 
         addInt(b.length);
 
