@@ -37,8 +37,7 @@ public class Ajp13Parser implements Parser
     private final static int STATE_START = -1;
     private final static int STATE_END = 0;
     private final static int STATE_AJP13CHUNK_START = 1;
-    private final static int STATE_AJP13CHUNK_START_AFTER_LENGTH = 2;
-    private final static int STATE_AJP13CHUNK = 3;
+    private final static int STATE_AJP13CHUNK = 2;
 
     private int _state = STATE_START;
     private long _contentLength;
@@ -522,12 +521,12 @@ public class Ajp13Parser implements Parser
             switch (_state)
             {
                 case STATE_AJP13CHUNK_START:
-                    if (_buffer.length()<4)
+                    if (_buffer.length()<6)
                     {
                         if (total_filled<0) 
                             total_filled=0;
                         total_filled+=fill();
-                        if (_buffer.length()<4)
+                        if (_buffer.length()<6)
                             return total_filled;
                     }
                     int _magic=Ajp13RequestPacket.getInt(_buffer);
@@ -537,28 +536,16 @@ public class Ajp13Parser implements Parser
                                 +Integer.toHexString(Ajp13RequestHeaders.MAGIC)+" "+this);
                     }
                     _chunkPosition=0;
-                    int rawChunkLength=Ajp13RequestPacket.getInt(_buffer);
-                    _chunkLength = rawChunkLength - 2;
-                    if (rawChunkLength==0 || _chunkLength==0)
+                    _chunkLength=Ajp13RequestPacket.getInt(_buffer)-2;
+                    Ajp13RequestPacket.getInt(_buffer);
+                    if (_chunkLength==0)
                     {
                         _state=STATE_END;
                          _generator.gotBody();
                         _handler.messageComplete(_contentPosition);
                         return total_filled;
                     }
-                    _state=STATE_AJP13CHUNK_START_AFTER_LENGTH;
-
-                case STATE_AJP13CHUNK_START_AFTER_LENGTH:
-                    if (_buffer.length() < 2)
-                    {
-                        if (total_filled < 0)
-                            total_filled = 0;
-                        total_filled += fill();
-                        if (_buffer.length() < 2)
-                            return total_filled;
-                    }
-                    Ajp13RequestPacket.getInt(_buffer);
-                    _state = STATE_AJP13CHUNK;
+                    _state=STATE_AJP13CHUNK;
 
                 case STATE_AJP13CHUNK:
                     if (_buffer.length()<_chunkLength)
