@@ -75,26 +75,32 @@ public class HttpExchange
     public static final int STATUS_EXPIRED = 8;
     public static final int STATUS_EXCEPTED = 9;
 
+    Address _address;
     String _method = HttpMethods.GET;
     Buffer _scheme = HttpSchemes.HTTP_BUFFER;
-    String _uri;
     int _version = HttpVersions.HTTP_1_1_ORDINAL;
-    Address _address;
+    String _uri;
+    int _status = STATUS_START;
     HttpFields _requestFields = new HttpFields();
     Buffer _requestContent;
     InputStream _requestContentSource;
-    long _timeout = -1;
-
-    volatile int _status = STATUS_START;
     Buffer _requestContentChunk;
     boolean _retryStatus = false;
-    // controls if the exchange will have listeners autoconfigured by the destination
+
+
+    /**
+     * boolean controlling if the exchange will have listeners autoconfigured by
+     * the destination
+     */
     boolean _configureListeners = true;
+
+
     private HttpEventListener _listener = new Listener();
 
-    boolean _onRequestCompleteDone;
-    boolean _onResponseCompleteDone;
-    boolean _onDone; // == onConnectionFail || onException || onExpired || onCancelled || onResponseCompleted && onRequestCompleted
+    /* ------------------------------------------------------------ */
+    /* ------------------------------------------------------------ */
+    /* ------------------------------------------------------------ */
+    // methods to build request
 
     /* ------------------------------------------------------------ */
     public int getStatus()
@@ -118,29 +124,14 @@ public class HttpExchange
     }
 
 
-    /**
-     * Wait until the exchange is "done".  
-     * Done is defined as when a final state has been passed to the 
-     * HttpExchange via the associated onXxx call.  Note that an
-     * exchange can transit a final state when being used as part
-     * of a dialog (eg {@link SecurityListener}.   Done status
-     * is thus defined as:<pre>
-     *   done == onConnectionFailed 
-     *        || onException
-     *        || onExpire
-     *        || onRequestComplete && onResponseComplete
-     * </pre>
-     * @return
-     * @throws InterruptedException
-     */
     public int waitForDone () throws InterruptedException
     {
         synchronized (this)
         {
             while (!isDone(_status))
                 this.wait();
-            return _status;
         }
+        return _status;
     }
 
 
@@ -149,70 +140,62 @@ public class HttpExchange
     /* ------------------------------------------------------------ */
     public void reset()
     {
-        // TODO - this should do a cancel and wakeup everybody that was waiting.
-        // might need a version number concept 
-        synchronized(this)
-        {
-            _onRequestCompleteDone=false;
-            _onResponseCompleteDone=false;
-            _onDone=false;
-            setStatus(STATUS_START);
-        }
+        setStatus(STATUS_START);
     }
 
     /* ------------------------------------------------------------ */
     void setStatus(int status)
     {
-        // _status is volatile
-        _status = status;
-
-        try
+        synchronized (this)
         {
-            switch (status)
+            _status = status;
+            this.notifyAll();
+
+            try
             {
-                case STATUS_WAITING_FOR_CONNECTION:
-                    break;
+                switch (status)
+                {
+                    case STATUS_WAITING_FOR_CONNECTION:
+                        break;
 
-                case STATUS_WAITING_FOR_COMMIT:
-                    break;
+                    case STATUS_WAITING_FOR_COMMIT:
+                        break;
 
-                case STATUS_SENDING_REQUEST:
-                    break;
+                    case STATUS_SENDING_REQUEST:
+                        break;
 
-                case HttpExchange.STATUS_WAITING_FOR_RESPONSE:
-                    getEventListener().onRequestCommitted();
-                    break;
+                    case HttpExchange.STATUS_WAITING_FOR_RESPONSE:
+                        getEventListener().onRequestCommitted();
+                        break;
 
-                case STATUS_PARSING_HEADERS:
-                    break;
+                    case STATUS_PARSING_HEADERS:
+                        break;
 
-                case STATUS_PARSING_CONTENT:
-                    getEventListener().onResponseHeaderComplete();
-                    break;
+                    case STATUS_PARSING_CONTENT:
+                        getEventListener().onResponseHeaderComplete();
+                        break;
 
-                case STATUS_COMPLETED:
-                    getEventListener().onResponseComplete();
-                    break;
+                    case STATUS_COMPLETED:
+                        getEventListener().onResponseComplete();
+                        break;
 
-                case STATUS_EXPIRED:
-                    getEventListener().onExpire();
-                    break;
+                    case STATUS_EXPIRED:
+                        getEventListener().onExpire();
+                        break;
 
+                }
+            }
+            catch (IOException e)
+            {
+                Log.warn(e);
             }
-        }
-        catch (IOException e)
-        {
-            Log.warn(e);
         }
     }
 
     /* ------------------------------------------------------------ */
     public boolean isDone (int status)
     {
-        synchronized (this)
-        {
-            return _onDone;
-        }
+        return ((status == STATUS_COMPLETED) || (status == STATUS_EXPIRED) || (status == STATUS_EXCEPTED));
     }
 
     /* ------------------------------------------------------------ */
@@ -437,8 +420,6 @@ public class HttpExchange
     public void setRequestContentSource(InputStream in)
     {
         _requestContentSource = in;
-        if (_requestContentSource.markSupported())
-            _requestContentSource.mark(Integer.MAX_VALUE);
     }
 
     /* ------------------------------------------------------------ */
@@ -478,29 +459,15 @@ public class HttpExchange
         return _requestContent;
     }
 
-    /* ------------------------------------------------------------ */
     public boolean getRetryStatus()
     {
         return _retryStatus;
     }
 
-    /* ------------------------------------------------------------ */
     public void setRetryStatus( boolean retryStatus )
     {
         _retryStatus = retryStatus;
     }
-    
-    /* ------------------------------------------------------------ */
-    public long getTimeout()
-    {
-        return _timeout;
-    }
-
-    /* ------------------------------------------------------------ */
-    public void setTimeout(long timeout)
-    {
-        _timeout = timeout;
-    }
 
     /* ------------------------------------------------------------ */
     /** Cancel this exchange
@@ -514,7 +481,7 @@ public class HttpExchange
     /* ------------------------------------------------------------ */
     public String toString()
     {
-        return getClass().getName() + "@" + hashCode() + "=" + _method + "//" + _address + _uri + "#" + _status;
+        return "HttpExchange@" + hashCode() + "=" + _method + "//" + _address.getHost() + ":" + _address.getPort() + _uri + "#" + _status;
     }
 
 
@@ -523,116 +490,51 @@ public class HttpExchange
     /* ------------------------------------------------------------ */
     /* ------------------------------------------------------------ */
     // methods to handle response
-    
-    /**
-     * Called when the request headers has been sent
-     * @throws IOException
-     */
     protected void onRequestCommitted() throws IOException
     {
     }
 
-    /**
-     * Called when the request and it's body have been sent.
-     * @throws IOException
-     */
     protected void onRequestComplete() throws IOException
     {
     }
 
-    /**
-     * Called when a response status line has been received.
-     * @param version HTTP version
-     * @param status HTTP status code
-     * @param reason HTTP status code reason string
-     * @throws IOException
-     */
     protected void onResponseStatus(Buffer version, int status, Buffer reason) throws IOException
     {
     }
 
-    /**
-     * Called for each response header received
-     * @param name header name
-     * @param value header value
-     * @throws IOException
-     */
     protected void onResponseHeader(Buffer name, Buffer value) throws IOException
     {
     }
 
-    /**
-     * Called when the response header has been completely received.
-     * @throws IOException
-     */
     protected void onResponseHeaderComplete() throws IOException
     {
     }
 
-    /**
-     * Called for each chunk of the response content received.
-     * @param content
-     * @throws IOException
-     */
     protected void onResponseContent(Buffer content) throws IOException
     {
     }
 
-    /**
-     * Called when the entire response has been received
-     * @throws IOException
-     */
     protected void onResponseComplete() throws IOException
     {
     }
 
-    /**
-     * Called when an exception was thrown during an attempt to open a connection
-     * @param ex
-     */
     protected void onConnectionFailed(Throwable ex)
     {
         Log.warn("CONNECTION FAILED on " + this,ex);
     }
 
-    /**
-     * Called when any other exception occurs during handling for the exchange
-     * @param ex
-     */
     protected void onException(Throwable ex)
     {
         Log.warn("EXCEPTION on " + this,ex);
     }
 
-    /**
-     * Called when no response has been received within the timeout.
-     */
     protected void onExpire()
     {
         Log.warn("EXPIRED " + this);
     }
 
-    /**
-     * Called when the request is retried (due to failures or authentication).
-     * Implementations may need to reset any consumable content that needs to
-     * be sent.
-     * @throws IOException
-     */
     protected void onRetry() throws IOException
-    {
-        if (_requestContentSource != null)
-        {
-            if (_requestContentSource.markSupported())
-            {
-                _requestContent = null;
-                _requestContentSource.reset();
-            }
-            else
-            {
-                throw new IOException("Unsupported retry attempt");
-            }
-        }
-    }
+    {}
 
     /**
      * true of the exchange should have listeners configured for it by the destination
@@ -655,50 +557,17 @@ public class HttpExchange
     {
         public void onConnectionFailed(Throwable ex)
         {
-            try
-            {
-                HttpExchange.this.onConnectionFailed(ex);
-            }
-            finally
-            {
-                synchronized(HttpExchange.this)
-                {
-                    _onDone=true;
-                    HttpExchange.this.notifyAll();
-                }
-            }
+            HttpExchange.this.onConnectionFailed(ex);
         }
 
         public void onException(Throwable ex)
         {
-            try
-            {
-                HttpExchange.this.onException(ex);
-            }
-            finally
-            {
-                synchronized(HttpExchange.this)
-                {
-                    _onDone=true;
-                    HttpExchange.this.notifyAll();
-                }
-            }
+            HttpExchange.this.onException(ex);
         }
 
         public void onExpire()
         {
-            try
-            {
-                HttpExchange.this.onExpire();
-            }
-            finally
-            {
-                synchronized(HttpExchange.this)
-                {
-                    _onDone=true;
-                    HttpExchange.this.notifyAll();
-                }
-            }
+            HttpExchange.this.onExpire();
         }
 
         public void onRequestCommitted() throws IOException
@@ -708,36 +577,12 @@ public class HttpExchange
 
         public void onRequestComplete() throws IOException
         {
-            try
-            {
-                HttpExchange.this.onRequestComplete();
-            }
-            finally
-            {
-                synchronized(HttpExchange.this)
-                {
-                    _onRequestCompleteDone=true;
-                    _onDone=_onResponseCompleteDone;
-                    HttpExchange.this.notifyAll();
-                }
-            }
+            HttpExchange.this.onRequestComplete();
         }
 
         public void onResponseComplete() throws IOException
         {
-            try
-            {
-                HttpExchange.this.onResponseComplete();
-            }
-            finally
-            {
-                synchronized(HttpExchange.this)
-                {
-                    _onResponseCompleteDone=true;
-                    _onDone=_onRequestCompleteDone;
-                    HttpExchange.this.notifyAll();
-                }
-            }
+            HttpExchange.this.onResponseComplete();
         }
 
         public void onResponseContent(Buffer content) throws IOException
@@ -769,7 +614,7 @@ public class HttpExchange
             }
             catch (IOException e)
             {
-                onException(e);
+                e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
             }
         }
     }
