@@ -115,7 +115,6 @@ public class SslSelectChannelConnector extends SelectChannelConnector
     private int _applicationBufferSize;
     private ConcurrentLinkedQueue<Buffer> _packetBuffers = new ConcurrentLinkedQueue<Buffer>();
     private ConcurrentLinkedQueue<Buffer> _applicationBuffers = new ConcurrentLinkedQueue<Buffer>();
-    private boolean _allowRenegotiate=false;
     
     /* ------------------------------------------------------------ */
     /* (non-Javadoc)
@@ -289,28 +288,6 @@ public class SslSelectChannelConnector extends SelectChannelConnector
         
     }
 
-    /* ------------------------------------------------------------ */
-    /**
-     * @return True if SSL re-negotiation is allowed (default false)
-     */
-    public boolean isAllowRenegotiate()
-    {
-        return _allowRenegotiate;
-    }
-
-    /* ------------------------------------------------------------ */
-    /**
-     * Set if SSL re-negotiation is allowed. CVE-2009-3555 discovered
-     * a vulnerability in SSL/TLS with re-negotiation.  If your JVM
-     * does not have CVE-2009-3555 fixed, then re-negotiation should 
-     * not be allowed.
-     * @param allowRenegotiate true if re-negotiation is allowed (default false)
-     */
-    public void setAllowRenegotiate(boolean allowRenegotiate)
-    {
-        _allowRenegotiate = allowRenegotiate;
-    }
-    
     /**
      * 
      * @deprecated As of Java Servlet API 2.0, with no replacement.
@@ -539,9 +516,7 @@ public class SslSelectChannelConnector extends SelectChannelConnector
     /* ------------------------------------------------------------------------------- */
     protected SelectChannelEndPoint newEndPoint(SocketChannel channel, SelectSet selectSet, SelectionKey key) throws IOException
     {
-        SslHttpChannelEndPoint endp = new SslHttpChannelEndPoint(this,channel,selectSet,key,createSSLEngine());
-        endp.setAllowRenegotiate(_allowRenegotiate);
-        return endp;
+        return new SslHttpChannelEndPoint(this,channel,selectSet,key,createSSLEngine());
     }
 
     /* ------------------------------------------------------------------------------- */
@@ -583,6 +558,7 @@ public class SslSelectChannelConnector extends SelectChannelConnector
 
                 engine.setEnabledCipherSuites(enabledCipherSuites);
             }
+
         }
         catch (Exception e)
         {
@@ -592,16 +568,19 @@ public class SslSelectChannelConnector extends SelectChannelConnector
         }
         return engine;
     }
+
    
     protected void doStart() throws Exception
     {
         _context=createSSLContext();
-        SSLEngine engine=_context.createSSLEngine();
-        SSLSession session=engine.getSession();
-        if (getHeaderBufferSize()<session.getApplicationBufferSize())
-            setHeaderBufferSize(session.getApplicationBufferSize());
-        if (getRequestBufferSize()<session.getApplicationBufferSize())
-            setRequestBufferSize(session.getApplicationBufferSize());
+        
+        SSLEngine engine=createSSLEngine();
+        SSLSession ssl_session=engine.getSession();
+        
+        setHeaderBufferSize(ssl_session.getApplicationBufferSize());
+        setRequestBufferSize(ssl_session.getApplicationBufferSize());
+        setResponseBufferSize(ssl_session.getApplicationBufferSize());
+        
         super.doStart();
     }
 
