@@ -15,6 +15,7 @@
 package org.mortbay.io.nio;
 
 import java.io.IOException;
+import java.nio.channels.ByteChannel;
 import java.nio.channels.CancelledKeyException;
 import java.nio.channels.SelectableChannel;
 import java.nio.channels.SelectionKey;
@@ -26,6 +27,7 @@ import java.util.Iterator;
 import java.util.List;
 
 import org.mortbay.component.AbstractLifeCycle;
+import org.mortbay.component.LifeCycle;
 import org.mortbay.io.Connection;
 import org.mortbay.io.EndPoint;
 import org.mortbay.log.Log;
@@ -42,13 +44,9 @@ import org.mortbay.thread.Timeout;
  */
 public abstract class SelectorManager extends AbstractLifeCycle
 {
-    // TODO Tune these by approx system speed.
-    private static final int __JVMBUG_THRESHHOLD=Integer.getInteger("org.mortbay.io.nio.JVMBUG_THRESHHOLD",512).intValue();
-    private static final int __MONITOR_PERIOD=Integer.getInteger("org.mortbay.io.nio.MONITOR_PERIOD",1000).intValue();
-    private static final int __MAX_SELECTS=Integer.getInteger("org.mortbay.io.nio.MAX_SELECTS",15000).intValue();
-    private static final int __BUSY_PAUSE=Integer.getInteger("org.mortbay.io.nio.BUSY_PAUSE",50).intValue();
-    private static final int __BUSY_KEY=Integer.getInteger("org.mortbay.io.nio.BUSY_KEY",-1).intValue();
-    
+    private static final int __JVMBUG_THRESHHOLD=Integer.getInteger("org.mortbay.io.nio.JVMBUG_THRESHHOLD",128).intValue();
+    private static final int __JVMBUG_THRESHHOLD2=__JVMBUG_THRESHHOLD*2;
+    private static final int __JVMBUG_THRESHHOLD1=(__JVMBUG_THRESHHOLD2+__JVMBUG_THRESHHOLD)/2;
     private boolean _delaySelectKeyUpdate=true;
     private long _maxIdleTime;
     private long _lowResourcesConnections;
@@ -56,7 +54,10 @@ public abstract class SelectorManager extends AbstractLifeCycle
     private transient SelectSet[] _selectSet;
     private int _selectSets=1;
     private volatile int _set;
+    private boolean _jvmBug0;
+    private boolean _jvmBug1;
     
+
     /* ------------------------------------------------------------ */
     /**
      * @param maxIdleTime The maximum period in milli seconds that a connection may be idle before it is closed.
@@ -284,19 +285,8 @@ public abstract class SelectorManager extends AbstractLifeCycle
         private transient Timeout _retryTimeout;
         private transient Selector _selector;
         private transient int _setID;
-        private volatile boolean _selecting;
         private transient int _jvmBug;
-        private int _selects;
-        private long _monitorStart;
-        private long _monitorNext;
-        private boolean _pausing;
-        private SelectionKey _busyKey;
-        private int _busyKeyCount;
-        private long _log;
-        private int _paused;
-        private int _jvmFix0;
-        private int _jvmFix1;
-        private int _jvmFix2;
+        private volatile boolean _selecting;
         
         /* ------------------------------------------------------------ */
         SelectSet(int acceptorID) throws Exception
@@ -312,9 +302,6 @@ public abstract class SelectorManager extends AbstractLifeCycle
             _selector = Selector.open();
             _changes = new ArrayList[] {new ArrayList(),new ArrayList()};
             _change=0;
-            _monitorStart=System.currentTimeMillis();
-            _monitorNext=_monitorStart+__MONITOR_PERIOD;
-            _log=_monitorStart+60000;
         }
         
         /* ------------------------------------------------------------ */
@@ -367,6 +354,7 @@ public abstract class SelectorManager extends AbstractLifeCycle
                     _selecting=true;
                     selector=_selector;
                 }
+                
 
                 // Make any key changes required
                 for (int i = 0; i < changes.size(); i++)
@@ -415,7 +403,7 @@ public abstract class SelectorManager extends AbstractLifeCycle
                                 key.attach(endpoint);
                                 endpoint.dispatch();
                             }
-                            else if (channel.isOpen())
+                            else
                             {
                                 channel.register(selector,SelectionKey.OP_CONNECT,null);
                             }
@@ -432,7 +420,7 @@ public abstract class SelectorManager extends AbstractLifeCycle
                         else
                             throw new IllegalArgumentException(o.toString());
                     }
-                    catch (Exception e)
+                    catch (CancelledKeyException e)
                     {
                         if (isRunning())
                             Log.warn(e);
@@ -465,89 +453,32 @@ public abstract class SelectorManager extends AbstractLifeCycle
                     wait = retry_next;
     
                 // Do the select.
-                if (wait > 2) // TODO tune or configure this
+                if (wait > 10) // TODO tune or configure this
                 {
-                    // If we are in pausing mode
-                    if (_pausing)
-                    {
-                        try
-                        {
-                            Thread.sleep(__BUSY_PAUSE); // pause to reduce impact of  busy loop
-                        }
-                        catch(InterruptedException e)
-                        {
-                            Log.ignore(e);
-                        }
-                    }
-                        
                     long before=now;
                     int selected=selector.select(wait);
                     now = System.currentTimeMillis();
                     _idleTimeout.setNow(now);
                     _retryTimeout.setNow(now);
-                    _selects++;
 
-                    // Look for JVM bugs over a monitor period.
+                    // Look for JVM bugs
                     // http://bugs.sun.com/bugdatabase/view_bug.do?bug_id=6403933
                     // http://bugs.sun.com/view_bug.do?bug_id=6693490
-                    if (now>_monitorNext)
+                    if (__JVMBUG_THRESHHOLD>0 && selected==0 && wait>__JVMBUG_THRESHHOLD && (now-before)<(wait/2) )
                     {
-                        _selects=(int)(_selects*__MONITOR_PERIOD/(now-_monitorStart));
-                        _pausing=_selects>__MAX_SELECTS;
-                        if (_pausing)
-                            _paused++;
-                            
-                        _selects=0;
-                        _jvmBug=0;
-                        _monitorStart=now;
-                        _monitorNext=now+__MONITOR_PERIOD;
-                    }
-                    
-                    if (now>_log)
-                    {
-                        if (_paused>0)  
-                            Log.info(this+" Busy selector - injecting delay "+_paused+" times");
-
-                        if (_jvmFix2>0)
-                            Log.info(this+" JVM BUG(s) - injecting delay"+_jvmFix2+" times");
-
-                        if (_jvmFix1>0)
-                            Log.info(this+" JVM BUG(s) - recreating selector "+_jvmFix1+" times, canceled keys "+_jvmFix0+" times");
-
-                        else if(Log.isDebugEnabled() && _jvmFix0>0)
-                            Log.info(this+" JVM BUG(s) - canceled keys "+_jvmFix0+" times");
-                        _paused=0;
-                        _jvmFix2=0;
-                        _jvmFix1=0;
-                        _jvmFix0=0;
-                        _log=now+60000;
-                    }
-                    
-                    // If we see signature of possible JVM bug, increment count.
-                    if (selected==0 && wait>10 && (now-before)<(wait/2))
-                    {
-                        // Increment bug count and try a work around
                         _jvmBug++;
-                        if (_jvmBug>(__JVMBUG_THRESHHOLD))
-                        {
-                            try
-                            {
-                                if (_jvmBug==__JVMBUG_THRESHHOLD+1)
-                                    _jvmFix2++;
-                                    
-                                Thread.sleep(__BUSY_PAUSE); // pause to avoid busy loop
-                            }
-                            catch(InterruptedException e)
-                            {
-                                Log.ignore(e);
-                            }
-                        }
-                        else if (_jvmBug==__JVMBUG_THRESHHOLD)
+                        if (_jvmBug>=(__JVMBUG_THRESHHOLD2))
                         {
                             synchronized (this)
                             {
                                 // BLOODY SUN BUG !!!  Try refreshing the entire selector.
-                                _jvmFix1++;
+                                if (_jvmBug1)
+                                    Log.debug("seeing JVM BUG(s) - recreating selector");
+                                else
+                                {
+                                    _jvmBug1=true;
+                                    Log.info("seeing JVM BUG(s) - recreating selector");
+                                }
                                 
                                 final Selector new_selector = Selector.open();
                                 Iterator iterator = _selector.keys().iterator();
@@ -567,13 +498,20 @@ public abstract class SelectorManager extends AbstractLifeCycle
                                 }
                                 _selector.close();
                                 _selector=new_selector;
+                                _jvmBug=0;
                                 return;
                             }
                         }
-                        else if (_jvmBug%32==31) // heuristic attempt to cancel key 31,63,95,... loops
+                        else if (_jvmBug==__JVMBUG_THRESHHOLD || _jvmBug==__JVMBUG_THRESHHOLD1)
                         {
                             // Cancel keys with 0 interested ops
-                            int cancelled=0;
+                            if (_jvmBug0)
+                                Log.debug("seeing JVM BUG(s) - cancelling interestOps==0");
+                            else
+                            {
+                                _jvmBug0=true;
+                                Log.info("seeing JVM BUG(s) - cancelling interestOps==0");
+                            }
                             Iterator iter = selector.keys().iterator();
                             while(iter.hasNext())
                             {
@@ -581,39 +519,18 @@ public abstract class SelectorManager extends AbstractLifeCycle
                                 if (k.isValid()&&k.interestOps()==0)
                                 {
                                     k.cancel();
-                                    cancelled++;
                                 }
                             }
-                            if (cancelled>0)
-                                _jvmFix0++;
-                            
                             return;
                         }
                     }
-                    else if (__BUSY_KEY>0 && selected==1 && _selects>__MAX_SELECTS)
-                    {
-                        // Look for busy key
-                        SelectionKey busy = (SelectionKey)selector.selectedKeys().iterator().next();
-                        if (busy==_busyKey)
-                        {
-                            if (++_busyKeyCount>__BUSY_KEY && !(busy.channel() instanceof ServerSocketChannel))
-                            {
-                                SelectChannelEndPoint endpoint = (SelectChannelEndPoint)busy.attachment();
-                                Log.warn("Busy Key "+busy.channel()+" "+endpoint);
-                                busy.cancel();
-                                if (endpoint!=null)
-                                    endpoint.close();
-                            }
-                        }
-                        else
-                            _busyKeyCount=0;
-                        _busyKey=busy;
-                    }
+                    else
+                        _jvmBug=0;
                 }
                 else 
                 {
                     selector.selectNow();
-                    _selects++;
+                    _jvmBug=0;
                 }
 
                 // have we been destroyed while sleeping
@@ -636,9 +553,8 @@ public abstract class SelectorManager extends AbstractLifeCycle
                                 endpoint.doUpdateKey();
                             continue;
                         }
-                        
+
                         Object att = key.attachment();
-                        
                         if (att instanceof SelectChannelEndPoint)
                         {
                             SelectChannelEndPoint endpoint = (SelectChannelEndPoint)att;
@@ -795,7 +711,7 @@ public abstract class SelectorManager extends AbstractLifeCycle
         {
             return _selector;
         }
-        
+
         /* ------------------------------------------------------------ */
         void stop() throws Exception
         {
