@@ -310,7 +310,6 @@ public abstract class AbstractConnector extends AbstractBuffers implements Conne
     /* ------------------------------------------------------------ */
     protected void doStop() throws Exception
     {
-        Log.info("Stopped {}",this);
         try{close();} catch(IOException e) {Log.warn(e);}
         
         if (_threadPool==_server.getThreadPool())
@@ -686,16 +685,15 @@ public abstract class AbstractConnector extends AbstractBuffers implements Conne
         public void run()
         {   
             Thread current = Thread.currentThread();
-            String name;
             synchronized(AbstractConnector.this)
             {
                 if (_acceptorThread==null)
                     return;
                 
                 _acceptorThread[_acceptor]=current;
-                name =_acceptorThread[_acceptor].getName();
-                current.setName(name+" - Acceptor"+_acceptor+" "+AbstractConnector.this);
             }
+            String name =_acceptorThread[_acceptor].getName();
+            current.setName(name+" - Acceptor"+_acceptor+" "+AbstractConnector.this);
             int old_priority=current.getPriority();
             
             try
@@ -717,6 +715,7 @@ public abstract class AbstractConnector extends AbstractBuffers implements Conne
                     }
                     catch(ThreadDeath e)
                     {
+                        Log.warn(e);
                         throw e;
                     }
                     catch(Throwable e)
