@@ -18,15 +18,15 @@ package org.mortbay.jetty;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.PrintWriter;
+
 import javax.servlet.ServletInputStream;
 import javax.servlet.ServletOutputStream;
 import javax.servlet.http.HttpServletResponse;
 
 import org.mortbay.io.Buffer;
-import org.mortbay.io.BufferCache.CachedBuffer;
 import org.mortbay.io.Connection;
 import org.mortbay.io.EndPoint;
-import org.mortbay.io.RuntimeIOException;
+import org.mortbay.io.BufferCache.CachedBuffer;
 import org.mortbay.io.nio.SelectChannelEndPoint;
 import org.mortbay.log.Log;
 import org.mortbay.resource.Resource;
@@ -46,13 +46,13 @@ import org.mortbay.util.ajax.Continuation;
  * A connection is also the prime mechanism used by jetty to recycle objects
  * without pooling. The {@link Request},{@link Response}, {@link HttpParser},
  * {@link HttpGenerator} and {@link HttpFields} instances are all recycled for
- * the duration of a connection. Where appropriate, allocated buffers are also
+ * the duraction of a connection. Where appropriate, allocated buffers are also
  * kept associated with the connection via the parser and/or generator.
  * </p>
- *
- *
+ * 
+ * 
  * @author gregw
- *
+ * 
  */
 public class HttpConnection implements Connection
 {
@@ -106,7 +106,7 @@ public class HttpConnection implements Connection
     /* ------------------------------------------------------------ */
     /**
      * Constructor
-     *
+     * 
      */
     public HttpConnection(Connector connector, EndPoint endpoint, Server server)
     {
@@ -122,7 +122,7 @@ public class HttpConnection implements Connection
         _generator.setSendServerVersion(server.getSendServerVersion());
         _server = server;
     }
-
+    
     protected HttpConnection(Connector connector, EndPoint endpoint, Server server,
             Parser parser, Generator generator, Request request)
     {
@@ -252,7 +252,7 @@ public class HttpConnection implements Connection
     /* ------------------------------------------------------------ */
     /**
      * Find out if the request is INTEGRAL security.
-     *
+     * 
      * @param request
      * @return <code>true</code> if there is a {@link #getConnector() connector}
      *         and it considers <code>request</code> to be
@@ -471,14 +471,7 @@ public class HttpConnection implements Connection
                         more_in_buffer = false;
                     }
 
-                    if (more_in_buffer)
-                    {
-                        reset(false);
-                        more_in_buffer = _parser.isMoreInBuffer() || _endp.isBufferingInput();
-                    }
-                    else
-                        reset(true);
-
+                    reset(!more_in_buffer);
                     no_progress = 0;
                 }
 
@@ -520,10 +513,9 @@ public class HttpConnection implements Connection
             boolean retrying = false;
             boolean error = false;
             String threadName = null;
-            String info=null;
             try
             {
-                info = URIUtil.canonicalPath(_uri.getDecodedPath());
+                String info = URIUtil.canonicalPath(_uri.getDecodedPath());
                 if (info == null)
                     throw new HttpException(400);
                 _request.setPathInfo(info);
@@ -559,30 +551,18 @@ public class HttpConnection implements Connection
                 _response.sendError(e.getStatus(),e.getReason());
                 error = true;
             }
-            catch (RuntimeIOException e)
+            catch (Exception e)
             {
-                Log.debug(e);
+                Log.warn(e);
                 _request.setHandled(true);
+                _generator.sendError(500,null,null,true);
                 error = true;
             }
-            catch (Throwable e)
+            catch (Error e)
             {
-                if (e instanceof ThreadDeath)
-                    throw (ThreadDeath)e;
-
-                if (info==null)
-                {
-                    Log.warn(_uri+": "+e);
-                    Log.debug(e);
-                    _request.setHandled(true);
-                    _generator.sendError(400,null,null,true);
-                }
-                else
-                {
-                    Log.warn(""+_uri,e);
-                    _request.setHandled(true);
-                    _generator.sendError(500,null,null,true);
-                }
+                Log.warn(e);
+                _request.setHandled(true);
+                _generator.sendError(500,null,null,true);
                 error = true;
             }
             finally
@@ -627,27 +607,7 @@ public class HttpConnection implements Connection
         if (!_generator.isCommitted())
         {
             _generator.setResponse(_response.getStatus(),_response.getReason());
-            try
-            {
-                _generator.completeHeader(_responseFields,last);
-            }
-            catch(IOException io)
-            {
-                throw io;
-            }
-            catch(RuntimeException e)
-            {
-                Log.warn("header full: "+e);
-                if (Log.isDebugEnabled() && _generator instanceof HttpGenerator)
-                    Log.debug(((HttpGenerator)_generator)._header.toDetailString(),e);
-                
-                _response.reset();
-                _generator.reset(true);
-                _generator.setResponse(HttpStatus.ORDINAL_500_Internal_Server_Error,null);
-                _generator.completeHeader(_responseFields,HttpGenerator.LAST);
-                _generator.complete();
-                throw e;
-            }
+            _generator.completeHeader(_responseFields,last);
         }
         if (last)
             _generator.complete();
@@ -659,26 +619,7 @@ public class HttpConnection implements Connection
         if (!_generator.isCommitted())
         {
             _generator.setResponse(_response.getStatus(),_response.getReason());
-            try
-            {
-                _generator.completeHeader(_responseFields,HttpGenerator.LAST);
-            }
-            catch(IOException io)
-            {
-                throw io;
-            }
-            catch(RuntimeException e)
-            {
-                Log.warn("header full: "+e);
-                Log.debug(e);
-
-                _response.reset();
-                _generator.reset(true);
-                _generator.setResponse(HttpStatus.ORDINAL_500_Internal_Server_Error,null);
-                _generator.completeHeader(_responseFields,HttpGenerator.LAST);
-                _generator.complete();
-                throw e;
-            }
+            _generator.completeHeader(_responseFields,HttpGenerator.LAST);
         }
 
         _generator.complete();
@@ -738,7 +679,7 @@ public class HttpConnection implements Connection
         private String _charset;
 
         /*
-         *
+         * 
          * @see
          * org.mortbay.jetty.HttpParser.EventHandler#startRequest(org.mortbay
          * .io.Buffer, org.mortbay.io.Buffer, org.mortbay.io.Buffer)
@@ -778,7 +719,6 @@ public class HttpConnection implements Connection
             }
             catch (Exception e)
             {
-                Log.debug(e);
                 throw new HttpException(HttpStatus.ORDINAL_400_Bad_Request,null,e);
             }
         }
@@ -864,8 +804,6 @@ public class HttpConnection implements Connection
          */
         public void headerComplete() throws IOException
         {
-            if (_endp instanceof SelectChannelEndPoint)
-                ((SelectChannelEndPoint)_endp).scheduleIdle();
             _requests++;
             _generator.setVersion(_version);
             switch (_version)
@@ -935,8 +873,6 @@ public class HttpConnection implements Connection
          */
         public void content(Buffer ref) throws IOException
         {
-            if (_endp instanceof SelectChannelEndPoint)
-                ((SelectChannelEndPoint)_endp).scheduleIdle();
             if (_delayedHandling)
             {
                 _delayedHandling = false;
@@ -946,7 +882,7 @@ public class HttpConnection implements Connection
 
         /*
          * (non-Javadoc)
-         *
+         * 
          * @see org.mortbay.jetty.HttpParser.EventHandler#messageComplete(int)
          */
         public void messageComplete(long contentLength) throws IOException
@@ -960,7 +896,7 @@ public class HttpConnection implements Connection
 
         /*
          * (non-Javadoc)
-         *
+         * 
          * @see
          * org.mortbay.jetty.HttpParser.EventHandler#startResponse(org.mortbay
          * .io.Buffer, int, org.mortbay.io.Buffer)
@@ -1057,13 +993,13 @@ public class HttpConnection implements Connection
                                 _responseFields.put(HttpHeaders.CONTENT_TYPE_BUFFER, content_type);
                             else
                             {
-                                _responseFields.put(HttpHeaders.CONTENT_TYPE_BUFFER,
+                                _responseFields.put(HttpHeaders.CONTENT_TYPE_BUFFER, 
                                         contentType+";charset="+QuotedStringTokenizer.quote(enc,";= "));
                             }
                         }
                         else
                         {
-                            _responseFields.put(HttpHeaders.CONTENT_TYPE_BUFFER,
+                            _responseFields.put(HttpHeaders.CONTENT_TYPE_BUFFER, 
                                     contentType+";charset="+QuotedStringTokenizer.quote(enc,";= "));
                         }
                     }
