@@ -1046,24 +1046,9 @@ public class HttpFields
     {
         try
         {
-            StringBuffer buffer = new StringBuffer();
-          
-            for (int i = 0; i < _fields.size(); i++)
-            {
-                Field field = (Field) _fields.get(i);
-                if (field != null && field._revision == _revision)
-                {
-                    String tmp = field.getName();
-                    if (tmp != null) buffer.append(tmp);
-                    buffer.append(": ");
-                    tmp = field.getValue();
-                    if (tmp != null) buffer.append(tmp);
-                    buffer.append("\r\n");
-                }
-            } 
-            buffer.append("\r\n");
-            return buffer.toString();
-            
+            ByteArrayBuffer buffer = new ByteArrayBuffer(4096);
+            put(buffer);
+            return BufferUtil.to8859_1_String(buffer);
         }
         catch (Exception e)
         {
@@ -1102,10 +1087,7 @@ public class HttpFields
             for (int i = _fields.size(); i-- > 0;)
             {
                 Field field = (Field) _fields.get(i);
-                if (field != null) {
-                    _bufferMap.remove(field.getNameBuffer());
-                    field.destroy();
-                }
+                if (field != null) field.destroy();
             }
         }
         _fields = null;
