@@ -465,15 +465,7 @@ public class HttpParser implements Parser
                                         case HttpHeaders.CONTENT_LENGTH_ORDINAL:
                                             if (_contentLength != HttpTokens.CHUNKED_CONTENT)
                                             {
-                                                try
-                                                {
-                                                    _contentLength=BufferUtil.toLong(value);
-                                                }
-                                                catch(NumberFormatException e)
-                                                {
-                                                    Log.ignore(e);
-                                                    throw new HttpException(HttpServletResponse.SC_BAD_REQUEST);
-                                                }
+                                                _contentLength=BufferUtil.toLong(value);
                                                 if (_contentLength <= 0)
                                                     _contentLength=HttpTokens.NO_CONTENT;
                                             }
@@ -1142,9 +1134,9 @@ public class HttpParser implements Parser
                 try
                 {
                     _parser.parseNext();
-                    
+
                     // parse until some progress is made (or IOException thrown for timeout)
-                    while(_contentView.length() == 0 && !_parser.isState(HttpParser.STATE_END) && _endp.isOpen())
+                    while(_contentView.length() == 0 && !_parser.isState(HttpParser.STATE_END))
                     {
                         // Try to get more _parser._content
                         _parser.parseNext();
@@ -1161,11 +1153,8 @@ public class HttpParser implements Parser
                 _parser.parseNext();
                 
                 // parse until some progress is made (or IOException thrown for timeout)
-                while(_contentView.length() == 0 && !_parser.isState(HttpParser.STATE_END) && _endp.isOpen())
+                while(_contentView.length() == 0 && !_parser.isState(HttpParser.STATE_END))
                 {
-                    if (_endp.isBufferingInput() && _parser.parseNext()>0)
-                        continue;
-                    
                     if (!_endp.blockReadable(_maxIdleTime))
                     {
                         _endp.close();
