@@ -154,8 +154,7 @@ public class ResourceHandler extends AbstractHandler
         }
         catch (Exception e)
         {
-            Log.warn(e.toString());
-            Log.debug(e);
+            Log.warn(e);
             throw new IllegalArgumentException(resourceBase);
         }
     }
@@ -280,7 +279,7 @@ public class ResourceHandler extends AbstractHandler
         {
             if (!request.getPathInfo().endsWith(URIUtil.SLASH))
             {
-                response.sendRedirect(response.encodeRedirectURL(URIUtil.addPaths(request.getRequestURI(),URIUtil.SLASH)));
+                response.sendRedirect(URIUtil.addPaths(request.getRequestURI(),URIUtil.SLASH));
                 return;
             }
             resource=getWelcome(resource);
