@@ -36,7 +36,6 @@ import javax.servlet.UnavailableException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
-import org.mortbay.io.RuntimeIOException;
 import org.mortbay.jetty.EofException;
 import org.mortbay.jetty.HttpConnection;
 import org.mortbay.jetty.HttpException;
@@ -401,10 +400,6 @@ public class ServletHandler extends AbstractHandler
         {
             throw e;
         }
-        catch(RuntimeIOException e)
-        {
-            throw e;
-        }
         catch(Exception e)
         {
             if (type!=REQUEST)
