@@ -340,15 +340,6 @@ public class ServletHolder extends Holder
         return _servlet;
     }
 
-    /* ------------------------------------------------------------ */
-    /** Get the servlet instance (no initialization done).
-     * @return The servlet or null
-     */
-    public Servlet getServletInstance()
-    {
-        return _servlet;
-    }
-    
     /* ------------------------------------------------------------ */
     /**
      * Check to ensure class of servlet is acceptable.
