@@ -1,5 +1,5 @@
 //========================================================================
-//$Id: JspcMojo.java 5477 2009-08-27 03:03:38Z janb $
+//$Id: JspcMojo.java 5283 2009-07-01 09:35:40Z dyu $
 //Copyright 2006 Mort Bay Consulting Pty. Ltd.
 //------------------------------------------------------------------------
 //Licensed under the Apache License, Version 2.0 (the "License");
@@ -333,7 +333,11 @@ public class JspcMojo extends AbstractMojo
         // delete the .java files - depending on keepGenerated setting
         if (!keepSources)
         {
-            File generatedClassesDir = new File(generatedClasses);
+            String packageRootDirectory = packageRoot.replace('.',
+                    File.separatorChar);
+
+            File generatedClassesDir = new File(generatedClasses
+                    + File.separatorChar + packageRootDirectory);
 
             if(generatedClassesDir.exists() && generatedClassesDir.isDirectory())
             {
