@@ -16,6 +16,8 @@ package org.mortbay.util.ajax;
 import java.io.StringReader;
 import java.lang.reflect.Array;
 import java.math.BigDecimal;
+import java.text.DateFormatSymbols;
+import java.text.SimpleDateFormat;
 import java.util.Date;
 import java.util.HashMap;
 import java.util.Locale;
@@ -24,6 +26,7 @@ import java.util.TimeZone;
 
 import junit.framework.TestCase;
 
+import org.mortbay.util.DateCache;
 import org.mortbay.util.ajax.JSON.Output;
 
 public class JSONTest extends TestCase
@@ -40,9 +43,7 @@ public class JSONTest extends TestCase
     "\"empty\" : {}  ," +
     "\"map\" : {\"a\":-1.0e2}  ," +
     "\"array\" : [\"a\",-1.0e2,[],null,true,false]  ," +
-    "\"w0\":{\"class\":\"org.mortbay.util.ajax.JSONTest$Woggle\",\"name\":\"woggle0\",\"nested\":{\"class\":\"org.mortbay.util.ajax.JSONTest$Woggle\",\"name\":\"woggle1\",\"nested\":null,\"number\":-101},\"number\":100}," +
-    "\"NaN\": NaN," + 
-    "\"undefined\": undefined," +
+    "\"w0\":{\"class\":\"org.mortbay.util.ajax.JSONTest$Woggle\",\"name\":\"woggle0\",\"nested\":{\"class\":\"org.mortbay.util.ajax.JSONTest$Woggle\",\"name\":\"woggle1\",\"nested\":null,\"number\":-101},\"number\":100}" +
     "}";
     
     public void testToString()
@@ -75,7 +76,6 @@ public class JSONTest extends TestCase
         obj7.put("x","value");
         
         String s = JSON.toString(map);
-        System.err.println(s);
         assertTrue(s.indexOf("\"n1\":null")>=0);
         assertTrue(s.indexOf("\"n2\":2")>=0);
         assertTrue(s.indexOf("\"n3\":-3.0E-11")>=0);
@@ -92,7 +92,6 @@ public class JSONTest extends TestCase
         gadget.setWoggles(new Woggle[]{w0,w1});
         
         s = JSON.toString(new Gadget[]{gadget});
-        System.err.println(s);
         assertTrue(s.startsWith("["));
         assertTrue(s.indexOf("\"modulated\":false")>=0);
         assertTrue(s.indexOf("\"shields\":42")>=0);
@@ -112,6 +111,8 @@ public class JSONTest extends TestCase
         JSON.registerConvertor(Gadget.class,new JSONObjectConvertor(false));
     }
 
+
+
     /* ------------------------------------------------------------ */
     public void testParse()
     {
@@ -123,13 +124,12 @@ public class JSONTest extends TestCase
         assertTrue(map.get("w0") instanceof Woggle);
         assertTrue(((Woggle)map.get("w0")).nested instanceof Woggle);
         assertEquals(-101,((Woggle)((Woggle)map.get("w0")).nested).number);
-        assertTrue(map.containsKey("NaN"));
-        assertEquals(null,map.get("NaN"));
-        assertTrue(map.containsKey("undefined"));
-        assertEquals(null,map.get("undefined"));
+        
         
         test="{\"data\":{\"source\":\"15831407eqdaawf7\",\"widgetId\":\"Magnet_8\"},\"channel\":\"/magnets/moveStart\",\"connectionId\":null,\"clientId\":\"15831407eqdaawf7\"}";
         map = (Map)JSON.parse(test);
+
+        
     }
 
     /* ------------------------------------------------------------ */
